@@ -316,8 +316,7 @@ class vizzy_sentence:
  
         
 class vizzy_token:
-    def __init__(sel
-f, dataframe, text, labels=None):
+    def __init__(self, dataframe, text, labels=None):
         self.data = dataframe
         self.text = text
         self.labels = labels
